Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(29)

Unified Diff: ash/common/system/tray/system_tray_item.h

Issue 2190773002: Fix Volume slider is captured in screenshot done in touchview mode (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: nits Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/common/system/tray/system_tray.cc ('k') | ash/common/system/tray/system_tray_item.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/system/tray/system_tray_item.h
diff --git a/ash/common/system/tray/system_tray_item.h b/ash/common/system/tray/system_tray_item.h
index 4925f6a81c67cf2349d5711568f196270ea7ad16..b83c2dff45b942f718ba345406e1f2490fe9ede3 100644
--- a/ash/common/system/tray/system_tray_item.h
+++ b/ash/common/system/tray/system_tray_item.h
@@ -121,8 +121,9 @@ class ASH_EXPORT SystemTrayItem {
// currently-shown view is for this item.
void SetDetailedViewCloseDelay(int for_seconds);
- // Hides the detailed view for this item.
- void HideDetailedView();
+ // Hides the detailed view for this item. Disable hiding animation if
+ // |animate| is false.
+ void HideDetailedView(bool animate);
// Shows a notification for this item.
void ShowNotificationView();
« no previous file with comments | « ash/common/system/tray/system_tray.cc ('k') | ash/common/system/tray/system_tray_item.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698